import os
import argparse
from github import Github, Auth

def auth():
    access_token = os.getenv("GITHUB_ACCESS_TOKEN")
    if not access_token:
        raise ValueError("GITHUB_ACCESS_TOKEN environment variable not set")
    auth = Auth.Token(access_token)
    g = Github(auth=auth)
    return g

class GithubSearcher():
    def __init__(self, query):
        self.g = auth()
        self.query = query
        self.result = None

    def search_repo(self):
        self.result = self.g.search_repositories(self.query)

    def search_users(self):
        self.result = self.g.search_users(self.query)

    def search_in_name(self):
        self.result = self.g.search_repositories('in:name ' + self.query)

    def get_repo_open_issues(self, repo):
        return repo.get_issues(state='open')

    def get_repo_contents(self, repo):
        contents = repo.get_contents()
        for content_file in contents:
            print(content_file)
        
        return contents

    def get_result(self):
        return self.result

def main():
    parser = argparse.ArgumentParser(description="Search GitHub repositories and users.")
    parser.add_argument("--query", type=str, help="The search query.")
    parser.add_argument("--search_type", type=str, choices=["repo", "users", "name"], help="The type of search to perform: 'repo', 'users', or 'name'.")
    parser.add_argument("--get_file_contents", action="store_true", help="Get the contents of a repository.")
    parser.add_argument("--get_open_issues", action="store_true", help="Get the open issues of a repository.")
    args = parser.parse_args()

    searcher = GithubSearcher(args.query)

    if args.search_type == "repo":
        searcher.search_repo()
    elif args.search_type == "users":
        searcher.search_users()
    elif args.search_type == "name":
        searcher.search_in_name()

    result = searcher.get_result()
    if result is None:
        print("No results found.")
        return

    for item in result:
        if args.search_type == "users":
            user_repos = item.get_repos()
            for repo in user_repos:
                print(repo.html_url)
        else:
            print(item.html_url)

            if args.get_open_issues:
                issues = searcher.get_repo_open_issues(item)
                if issues:
                    print("Open issues:")
                    for issue in issues:
                        print(f"Issue: {issue.title}")
                    print("\n")

            if args.get_file_contents:
                contents = searcher.get_repo_contents(item)
                if contents:
                    print("Contents:")
                    for content in contents:
                        print(f"File: {content.path}")
                    print("\n")

if __name__ == "__main__":
    main()